aboutsummaryrefslogtreecommitdiff
path: root/include/tss2
diff options
context:
space:
mode:
authorJuergen Repp <Juergen.Repp@sit.fraunhofer.de>2018-11-19 15:02:56 +0100
committerTadeusz Struk <tadeusz.struk@intel.com>2018-11-26 09:03:14 -0800
commit1b96f0e7298fbc18b95f7d9cff94c55276aee829 (patch)
tree0e7833f500fdea96bf2f250af6b7594d500ea0eb /include/tss2
parentef68d65a797bee45df2666e252ded960770fbd24 (diff)
downloadtpm2-tss-1b96f0e7298fbc18b95f7d9cff94c55276aee829.tar.gz
SYS: Fix wrong typename _ID_OBJECT in tss2_tpm2_types.h
* The type _ID_OBJECT is renamed to TPMS_ID_OBJECT as defined in "TCG TSS 2.0 Overview and Common Structures Specification". Signed-off-by: Juergen Repp <Juergen.Repp@sit.fraunhofer.de>
Diffstat (limited to 'include/tss2')
-rw-r--r--include/tss2/tss2_tpm2_types.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/tss2/tss2_tpm2_types.h b/include/tss2/tss2_tpm2_types.h
index 70ada99c..c31648e4 100644
--- a/include/tss2/tss2_tpm2_types.h
+++ b/include/tss2/tss2_tpm2_types.h
@@ -1630,16 +1630,16 @@ typedef struct {
BYTE buffer[sizeof(_PRIVATE)];
} TPM2B_PRIVATE;
/* Definition of _ID_OBJECT Structure <> */
typedef struct {
TPM2B_DIGEST integrityHMAC; /* HMAC using the nameAlg of the storage key on the target TPM */
TPM2B_DIGEST encIdentity; /* credential protector information returned if name matches the referenced objectAll of the encIdentity is encrypted including the size field. NOTE The TPM is not required to check that the size is not larger than the digest of the nameAlg. However if the size is larger the ID object may not be usable on a TPM that has no digest larger than produced by nameAlg. */
-} _ID_OBJECT;
+} TPMS_ID_OBJECT;
/* Definition of TPM2B_ID_OBJECT Structure <INOUT> */
typedef struct {
UINT16 size;
- BYTE credential[sizeof(_ID_OBJECT)];
+ BYTE credential[sizeof(TPMS_ID_OBJECT)];
} TPM2B_ID_OBJECT;
/* Definition of UINT32 TPM2_NV_INDEX Bits <> */
@@ -1630,16 +1630,16 @@ typedef struct {
BYTE buffer[sizeof(_PRIVATE)];
} TPM2B_PRIVATE;
-/* Definition of _ID_OBJECT Structure <> */
+/* Definition of TPMS_ID_OBJECT Structure <> */
typedef struct {
TPM2B_DIGEST integrityHMAC; /* HMAC using the nameAlg of the storage key on the target TPM */